.. Copyright 2021 CMakePP
..
.. Licensed under the Apache License, Version 2.0 (the "License");
.. you may not use this file except in compliance with the License.
.. You may obtain a copy of the License at
..
.. http://www.apache.org/licenses/LICENSE-2.0
..
.. Unless required by applicable law or agreed to in writing, software
.. distributed under the License is distributed on an "AS IS" BASIS,
.. WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
.. See the License for the specific language governing permissions and
.. limitations under the License.
..
##########
Quickstart
##########

CMinx assumes you've commented your custom CMake functions and macros like:

.. literalinclude:: ../../tests/test_samples/quickstart.cmake
   :language: cmake

Assuming that this function is defined in the file ``quickstart.cmake``, located
in your current working directory, reST documentation for this CMake module is
generated by running:

.. code:: console

   foo@bar:~$ cminx -o output_dir/ quickstart.cmake

The result will be in a file ``output_dir/quickstart.rst``.